@@ -1,7 +1,7 @@
 #  optsol_fluxdelClass.R
 #  FBA and friends with R.
 #
-#  Copyright (C) 2010-2012 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
+#  Copyright (C) 2010-2013 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
 #  Institute for Informatics, Heinrich-Heine-University, Duesseldorf, Germany.
 #  All right reserved.
 #  Email: geliudie@uni-duesseldorf.de
@@ -33,7 +33,7 @@ setClass("optsol_fluxdel",
            representation(
                chlb      = "numeric",      # lower bound of changed fluxes/genes
                chub      = "numeric",      # upper bound of changed fluxes/genes
-               dels      = "matrix"        # deleted fluxes (1 column)
+               dels      = "matrix"        # id's of deleted fluxes
            ),
            contains = "optsol_optimizeProb"
 )
@@ -73,7 +73,7 @@ setReplaceMethod("chub", signature = (object = "optsol_fluxdel"),
 )
 
 
-# deleted
+# dels
 setMethod("dels", signature(object = "optsol_fluxdel"),
           function(object) {
               return(object@dels)
