@@ -1,7 +1,7 @@
 #  zzz.R
 #  FBA and friends with R.
 #
-#  Copyright (C) 2010-2012 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
+#  Copyright (C) 2010-2013 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
 #  Institute for Informatics, Heinrich-Heine-University, Duesseldorf, Germany.
 #  All right reserved.
 #  Email: geliudie@uni-duesseldorf.de
@@ -107,9 +107,9 @@
 
 
     # -------------------------------------------------------------- #
-    # available algorithms for flux or gene deletion experiments
+    # algorithms simulation genetic perturbations
 
-    .SYBILenv$algorithm[["optimizer"]] <- c("fba", "moma", "lmoma", "room")
+    .SYBILenv$algorithm[["pert"]] <- c("fba", "mtf", "moma", "lmoma", "room")
 
 
     # -------------------------------------------------------------- #
